scxpand.pretrained.inference\_api
=================================

.. automodule:: scxpand.pretrained.inference_api

   
   .. rubric:: Functions

   .. autosummary::
   
      fetch_model_and_run_inference
   